@@ -145,6 +145,8 @@ class _ExpandingRollingMechanism:
         # Set initial index
         if t is not None:
             self.t = t
+        else :
+            self.t = 0
 
         # Set max index
         if T is None:
